@@ -33,24 +33,21 @@ test_that("build_wfs_req", {
    skip_on_cran()
    req_by_shp <- lapply(list(point, multipoint, line, multiline, poly, multipoly),
                           build_wfs_req,
-                          apikey = "altimetrie",
                           layer = "ELEVATION.CONTOUR.LINE:courbe",
                           spatial_filter = "within",
                           crs = 4326)
 
    cql_filters <- lapply(req_by_shp, function(x){x$body$data$cql_filter})
 
-   expect_match(cql_filters[[1]], "WITHIN%28the_geom%2C%20POINT%20%2847", fixed = T)
-   expect_match(cql_filters[[2]], "WITHIN%28the_geom%2C%20MULTIPOINT%20", fixed = T)
-   expect_match(cql_filters[[3]], "WITHIN%28the_geom%2C%20LINESTRING%20", fixed = T)
-   expect_match(cql_filters[[4]], "WITHIN%28the_geom%2C%20MULTILINESTRI", fixed = T)
-   expect_match(cql_filters[[5]], "WITHIN%28the_geom%2C%20POLYGON%20%28", fixed = T)
-   expect_match(cql_filters[[6]], "WITHIN%28the_geom%2C%20MULTIPOLYGON%", fixed = T)
+   expect_match(cql_filters[[1]], "WITHIN%28geom%2C%20POINT%20%2847", fixed = T)
+   expect_match(cql_filters[[2]], "WITHIN%28geom%2C%20MULTIPOINT%20", fixed = T)
+   expect_match(cql_filters[[3]], "WITHIN%28geom%2C%20LINESTRING%20", fixed = T)
+   expect_match(cql_filters[[4]], "WITHIN%28geom%2C%20MULTILINESTRI", fixed = T)
+   expect_match(cql_filters[[5]], "WITHIN%28geom%2C%20POLYGON%20%28", fixed = T)
+   expect_match(cql_filters[[6]], "WITHIN%28geom%2C%20MULTIPOLYGON%", fixed = T)
 
    # if x = NULL there cannot be any spatial filters
-   req <- build_wfs_req(x = NULL,
-                        apikey = "altimetrie",
-                        layer = "ELEVATION.CONTOUR.LINE:courbe",
+   req <- build_wfs_req(x = NULL,layer = "ELEVATION.CONTOUR.LINE:courbe",
                         spatial_filter = "within",
                         crs = 4326)
    ecql_filter <- req$body$data$cql_filter
@@ -58,14 +55,13 @@ test_that("build_wfs_req", {
 
    # combine spatial and ecql filter
    req <- build_wfs_req(x = point,
-                        apikey = "altimetrie",
                         layer = "ELEVATION.CONTOUR.LINE:courbe",
                         spatial_filter = "within",
                         ecql_filter = "ecql_filter1",
                         crs = 4326)
    ecql_filter <- req$body$data$cql_filter
    expect_match(ecql_filter,
-                "WITHIN%28the_geom%2C%20POINT%20%2847.813%20-4.344%29%29%20AND%20ecql_filter1",
+                "WITHIN%28geom%2C%20POINT%20%2847.813%20-4.344%29%29%20AND%20ecql_filter1",
                 fixed = T)
 })
 
@@ -75,13 +71,11 @@ with_mock_dir("wfs_intersect", {
       skip_on_ci()
       skip_if_offline()
 
-      apikey <- "administratif"
       layer <- "LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune"
       spatial_filter <- "intersects"
 
       get_wfs_by_shp <- lapply(list(point, multipoint, line, multiline, poly, multipoly),
                              get_wfs,
-                             apikey = "administratif",
                              layer = "LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune",
                              spatial_filter = "intersects")
 
@@ -99,12 +93,11 @@ with_mock_dir("wfs_ecql_filter", {
       skip_on_cran()
       skip_if_offline()
 
-      apikey <- "administratif"
       layer <- "LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune"
       spatial_filter <- NULL
       ecql_filter <- "nom_m LIKE 'PEN%RCH' AND population < 6000"
 
-      resp <- get_wfs(point, apikey, layer, NULL, spatial_filter, ecql_filter)
+      resp <- get_wfs(point, layer, NULL, spatial_filter, ecql_filter)
       expect_s3_class(resp, "sf")
       expect_equal(dim(resp), c(1,12))
       expect_true(st_drop_geometry(resp)[1,3] == "PENMARCH")
@@ -116,12 +109,10 @@ with_mock_dir("wfs_empty", {
       skip_on_cran()
       skip_if_offline()
 
-      apikey <- "administratif"
       layer <- "LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune"
       ecql_filter <- "nom_m LIKE 'BADNAME'"
 
-      expect_warning(get_wfs(apikey = apikey,
-                             layer = layer,
+      expect_warning(get_wfs(layer = layer,
                              ecql_filter = ecql_filter),
                      "No data found, NULL is returned.")
 })},
